@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.002004'; # VERSION
+our $VERSION = '1.003001'; # VERSION
 
 use parent 'Exporter';
 use Test::Builder;
@@ -38,19 +38,17 @@ sub import { ## no critic qw( Subroutines::RequireArgUnpacking Subroutines::Requ
 		:                                       1
 		;
 
+	my $mmv = version->parse( $Module::Metadata::VERSION );
+	my $rec = version->parse( '1.000020'  );
+	if ( $mmv >= $rec && ! defined $cfg->{ignore_unindexable} ) {
+		$cfg->{ignore_unindexable} = 1;
+	}
+
 	__PACKAGE__->export_to_level( 1, @exports );
 }
 
 my $version_counter = 0;
 
-
-sub _get_version {
-	my $pm = shift;
-
-	my $info = Module::Metadata->new_from_file( $pm );
-	return $info->version;
-}
-
 my $test = Test::Builder->new;
 
 sub version_ok {
@@ -62,7 +60,12 @@ sub version_ok {
 
 	croak "'$file' doesn't exist." unless -e $file;
 
-	my $version = _get_version( $file );
+	my $info = Module::Metadata->new_from_file( $file );
+	if ( $cfg->{ignore_unindexable} ) {
+		$test->skip( "$file not indexable" );
+		return 0 if ! $info->is_indexable;
+	}
+	my $version = $info->version;
 
 	if ( not $version and not $cfg->{has_version} ) {
 		$test->skip( 'No version was found in "'
@@ -152,7 +155,7 @@ Test::Version - Check to see that version's in modules are sane
 
 =head1 VERSION
 
-version 1.002004
+version 1.003001
 
 =head1 SYNOPSIS
 
@@ -242,6 +245,13 @@ really doesn't make sense to use with just L<version_ok|/version_ok>
 this allows enabling of L<version>s C<is_strict> checks to ensure that your
 version is strict.
 
+=head2 ignore_unindexable
+
+	use Test::Version { ignore_unindexable => 0};
+
+if you have at least L<Module::Metadata> vC<1.000020> Test::Version will by
+default skip any files not considered L<is_indexable|Module::Metadata/is_indexable>
+
 =head1 SEE ALSO
 
 The goal is to have the functionality of all of these.
@@ -267,6 +277,8 @@ feature.
 
 =head1 CONTRIBUTORS
 
+=for stopwords Graham Ollis Michael G. Schwern Mike Doherty particle
+
 =over 4
 
 =item *
@@ -293,7 +305,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Caleb Cushing.
+This software is Copyright (c) 2014 by Caleb Cushing.
 
 This is free software, licensed under:
 
